@@ -22,7 +22,13 @@ Ext.ux.RapiFs.Plugin.DblclickDownload = Ext.extend(Ext.util.Observable,{
         }catch(e){};
       },tree);
     }
-  
+    else {
+      tree.on('click',function(node,e) {
+        // Unless we're in dblclick_download mode, unselect after click
+        var sm = this.getSelectionModel();
+        sm.select(this.root);
+      },tree,{ delay: 200 });
+    }
   }
 
 });
